@@ -4,9 +4,9 @@ use strict;
 require Exporter;
 use vars qw/$VERSION @ISA @EXPORT @EXPORT_OK $DEBUG/;
 
-$VERSION    = '0.45';
-@ISA	    = 'Exporter';
-@EXPORT	    = qw/
+$VERSION    = '0.53';
+@ISA        = 'Exporter';
+@EXPORT     = qw/
   blib_to_par
   install_par
   uninstall_par
@@ -32,10 +32,6 @@ use File::Spec;
 
 PAR::Dist - Create and manipulate PAR distributions
 
-=head1 VERSION
-
-This document describes version 0.45 of PAR::Dist, released June 11, 2009.
-
 =head1 SYNOPSIS
 
 As a shell command:
@@ -46,11 +42,11 @@ In programs:
 
     use PAR::Dist;
 
-    my $dist = blib_to_par();	# make a PAR file using ./blib/
-    install_par($dist);		# install it into the system
-    uninstall_par($dist);	# uninstall it from the system
-    sign_par($dist);		# sign it using Module::Signature
-    verify_par($dist);		# verify it using Module::Signature
+    my $dist = blib_to_par(); # make a PAR file using ./blib/
+    install_par($dist);       # install it into the system
+    uninstall_par($dist);     # uninstall it from the system
+    sign_par($dist);          # sign it using Module::Signature
+    verify_par($dist);        # verify it using Module::Signature
 
     install_par("http://foo.com/DBI-1.37-MSWin32-5.8.0.par"); # works too
     install_par("http://foo.com/DBI-1.37"); # auto-appends archname + perlver
@@ -61,7 +57,7 @@ In programs:
 This module creates and manipulates I<PAR distributions>.  They are
 architecture-specific B<PAR> files, containing everything under F<blib/>
 of CPAN distributions after their C<make> or C<Build> stage, a
-F<META.yml> describing metadata of the original CPAN distribution, 
+F<META.yml> describing metadata of the original CPAN distribution,
 and a F<MANIFEST> detailing all files within it.  Digitally signed PAR
 distributions will also contain a F<SIGNATURE> file.
 
@@ -150,11 +146,11 @@ sub blib_to_par {
     # don't use 'my $foo ... if ...' it creates a static variable!
     my $quiet = $args{quiet} || 0;
     my $dist;
-    my $path	= $args{path};
-    $dist	= File::Spec->rel2abs($args{dist}) if $args{dist};
-    my $name	= $args{name};
-    my $version	= $args{version};
-    my $suffix	= $args{suffix} || "$Config::Config{archname}-$Config::Config{version}.par";
+    my $path    = $args{path};
+    $dist       = File::Spec->rel2abs($args{dist}) if $args{dist};
+    my $name    = $args{name};
+    my $version = $args{version};
+    my $suffix  = $args{suffix} || "$Config::Config{archname}-$Config::Config{version}.par";
     my $cwd;
 
     if (defined $path) {
@@ -168,7 +164,7 @@ sub blib_to_par {
     my @files;
     open MANIFEST, ">", File::Spec->catfile("blib", "MANIFEST") or die $!;
     open META, ">", File::Spec->catfile("blib", "META.yml") or die $!;
-    
+
     require File::Find;
     File::Find::find( sub {
         next unless $File::Find::name;
@@ -176,14 +172,18 @@ sub blib_to_par {
     } , 'blib' );
 
     print MANIFEST join(
-	"\n",
-	'    <!-- accessible as jar:file:///NAME.par!/MANIFEST in compliant browsers -->',
-	(sort @files),
-	q(    # <html><body onload="var X=document.body.innerHTML.split(/\n/);var Y='<iframe src=&quot;META.yml&quot; style=&quot;float:right;height:40%;width:40%&quot;></iframe><ul>';for(var x in X){if(!X[x].match(/^\s*#/)&&X[x].length)Y+='<li><a href=&quot;'+X[x]+'&quot;>'+X[x]+'</a>'}document.body.innerHTML=Y">)
+        "\n",
+        '    <!-- accessible as jar:file:///NAME.par!/MANIFEST in compliant browsers -->',
+        (sort @files),
+        q(    # <html><body onload="var X=document.body.innerHTML.split(/\n/);var Y='<iframe src=&quot;META.yml&quot; style=&quot;float:right;height:40%;width:40%&quot;></iframe><ul>';for(var x in X){if(!X[x].match(/^\s*#/)&&X[x].length)Y+='<li><a href=&quot;'+X[x]+'&quot;>'+X[x]+'</a>'}document.body.innerHTML=Y">)
     );
     close MANIFEST;
 
-    if (open(OLD_META, "META.yml")) {
+    # if MYMETA.yml exists, that takes precedence over META.yml
+    my $meta_file_name = "META.yml";
+    my $mymeta_file_name = "MYMETA.yml";
+    $meta_file_name = -s $mymeta_file_name ? $mymeta_file_name : $meta_file_name;
+    if (open(OLD_META, $meta_file_name)) {
         while (<OLD_META>) {
             if (/^distribution_type:/) {
                 print META "distribution_type: par\n";
@@ -196,21 +196,15 @@ sub blib_to_par {
                 $name ||= $1;
                 $name =~ s/::/-/g;
             }
-            elsif (/^version:\s+.*Module::Build::Version/) {
-                while (<OLD_META>) {
-                    /^\s+original:\s+(.*)/ or next;
-                    $version ||= $1;
-                    last;
-                }
-            }
-            elsif (/^version:\s+(.*)/) {
+            elsif (/^version:\s+(\S*)/) {
                 $version ||= $1;
+                $version =~ s/^['"]|['"]$//g;
             }
         }
         close OLD_META;
         close META;
     }
-    
+
     if ((!$name or !$version) and open(MAKEFILE, "Makefile")) {
         while (<MAKEFILE>) {
             if (/^DISTNAME\s+=\s+(.*)$/) {
@@ -232,11 +226,11 @@ sub blib_to_par {
         elsif (not defined $version) {
             $what = 'version';
         }
-        
+
         carp("I was unable to determine the $what of the PAR distribution. Please create a Makefile or META.yml file from which we can infer the information or just specify the missing information as an option to blib_to_par.");
         return();
     }
-    
+
     $name =~ s/\s+$//;
     $version =~ s/\s+$//;
 
@@ -245,7 +239,7 @@ sub blib_to_par {
 
     print META << "YAML" if fileno(META);
 name: $name
-version: $version
+version: '$version'
 build_requires: {}
 conflicts: {}
 dist_name: $file
@@ -372,7 +366,7 @@ file is written to. (Necessary for uninstallation.)
 The C<packlist_read> parameter specifies a .packlist file to merge in if
 it exists. By setting any of the above installation targets to C<undef>,
 you can remove that target altogether. For example, passing
-C<inst_man1dir => undef, inst_man3dir => undef> means that the contained
+C<< inst_man1dir => undef, inst_man3dir => undef >> means that the contained
 manual pages won't be installed. This is not available for the packlists.
 
 Again, the defaults will be the normal I<site> paths from C<%Config>.
@@ -431,7 +425,7 @@ sub _install_or_uninstall {
 
     require Cwd;
     my $old_dir = Cwd::cwd();
-    
+
     my ($dist, $tmpdir) = _unzip_to_tmpdir( dist => $args{dist}, subdir => 'blib' );
 
     if ( open (META, File::Spec->catfile('blib', 'META.yml')) ) {
@@ -461,7 +455,7 @@ sub _install_or_uninstall {
         my $target = _installation_target( File::Spec->curdir, $name, \%args );
         my $custom_targets = $args{custom_targets} || {};
         $target->{$_} = $custom_targets->{$_} foreach keys %{$custom_targets};
-        
+
         my $uninstall_shadows = $args{uninstall_shadows};
         my $verbose = $args{verbose};
         ExtUtils::Install::install($target, $verbose, 0, $uninstall_shadows);
@@ -525,7 +519,7 @@ sub _installation_target {
        $sources{inst_man1dir}   => $Config::Config{installman1dir},
        $sources{inst_man3dir}   => $Config::Config{installman3dir},
     };
-    
+
     # Included for future support for ${flavour}perl external lib installation
 #    if ($Config::Config{flavour_perl}) {
 #        my $ext = File::Spec->catdir($dir, 'blib', 'ext');
@@ -539,7 +533,7 @@ sub _installation_target {
 #        $target->{ $sources{inst_external_include} } = $Config::Config{flavour_install_include};
 #        $target->{ $sources{inst_external_src} }     = $Config::Config{flavour_install_src};
 #    }
-    
+
     # insert user overrides
     foreach my $key (keys %$user) {
         my $value = $user->{$key};
@@ -567,7 +561,7 @@ sub _directory_not_empty {
     my($dir) = @_;
     my $files = 0;
     File::Find::find(sub {
-	    return if $_ eq ".exists";
+        return if $_ eq ".exists";
         if (-f) {
             $File::Find::prune++;
             $files = 1;
@@ -609,7 +603,7 @@ sub verify_par {
 I<Note:> Since version 0.32 of PAR::Dist, this function requires a YAML
 reader. The order of precedence is:
 
-  YAML YAML::Syck YAML::Tiny YAML::XS
+  YAML:XS YAML YAML::Syck YAML::Tiny
 
 Merges two or more PAR distributions into one. First argument must
 be the name of the distribution you want to merge all others into.
@@ -643,7 +637,7 @@ sub merge_par {
     if (not -f $base_par or not -r _ or not -w _) {
         croak "'$base_par' is not a file or you do not have enough permissions to read and modify it.";
     }
-    
+
     foreach (@additional_pars) {
         if (not -f $_ or not -r _) {
             croak "'$_' is not a file or you do not have enough permissions to read it.";
@@ -652,7 +646,7 @@ sub merge_par {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $base_par, subdir => 'blib'
@@ -668,7 +662,7 @@ sub merge_par {
     # delete (incorrect) MANIFEST
     unlink File::Spec->catfile($blibdir, 'MANIFEST');
 
-    # extract additional pars and merge    
+    # extract additional pars and merge
     foreach my $par (@additional_pars) {
         # restore original directory because the par path
         # might have been relative!
@@ -697,7 +691,7 @@ sub merge_par {
         );
         my ($vol, $subdir, undef) = File::Spec->splitpath( $add_dir, 1);
         my @dir = File::Spec->splitdir( $subdir );
-    
+
         # merge directory structure
         foreach my $dir (@dirs) {
             my ($v, $d, undef) = File::Spec->splitpath( $dir, 1 );
@@ -718,21 +712,21 @@ sub merge_par {
             );
             File::Copy::copy($file, $target)
               or die "Could not copy '$file' to '$target': $!";
-            
+
         }
         chdir($old_cwd);
         File::Path::rmtree([$add_dir]);
     }
-    
+
     # delete (copied) MANIFEST and META.yml
     unlink File::Spec->catfile($blibdir, 'MANIFEST');
     unlink File::Spec->catfile($blibdir, 'META.yml');
-    
+
     chdir($base_dir);
     my $resulting_par_file = Cwd::abs_path(blib_to_par(quiet => 1));
     chdir($old_cwd);
     File::Copy::move($resulting_par_file, $base_par);
-    
+
     File::Path::rmtree([$base_dir]);
 }
 
@@ -759,7 +753,7 @@ sub _merge_meta {
 
   _merge_provides($orig_tree, $extra_tree);
   _merge_requires($orig_tree, $extra_tree);
-  
+
   $yaml_functions->{DumpFile}->($meta_orig_file, $orig_meta);
 
   return 1;
@@ -794,7 +788,7 @@ sub _merge_requires {
   foreach my $type (qw(requires build_requires configure_requires recommends)) {
     next if not exists $extra_hash->{$type};
     $orig_hash->{$type} ||= {};
-    
+
     # one level clone is enough wrt META spec 1.4
     foreach my $module (keys %{ $extra_hash->{$type} }) {
       # FIXME there should be a version comparison here, BUT how are we going to do that without a guaranteed version.pm?
@@ -832,10 +826,10 @@ sub remove_man {
     if (not -f $par or not -r _ or not -w _) {
         croak "'$par' is not a file or you do not have enough permissions to read and modify it.";
     }
-    
+
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $par, subdir => 'blib'
@@ -856,14 +850,14 @@ sub remove_man {
                map  { File::Spec->catfile('blib', $_) }
                readdir DIRECTORY;
     close DIRECTORY;
-    
+
     File::Path::rmtree(\@dirs);
-    
+
     chdir($base_dir);
     my $resulting_par_file = Cwd::abs_path(blib_to_par());
     chdir($old_cwd);
     File::Copy::move($resulting_par_file, $par);
-    
+
     File::Path::rmtree([$base_dir]);
 }
 
@@ -891,7 +885,7 @@ sub get_meta {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $dist, subdir => 'blib'
@@ -903,18 +897,18 @@ sub get_meta {
     if (not -r $meta) {
         return undef;
     }
-    
+
     open FH, '<', $meta
       or die "Could not open file '$meta' for reading: $!";
-    
+
     local $/ = undef;
     my $meta_text = <FH>;
     close FH;
-    
+
     chdir($old_cwd);
-    
+
     File::Path::rmtree([$base_dir]);
-    
+
     return $meta_text;
 }
 
@@ -1033,7 +1027,7 @@ sub _fetch {
     %escapes = map { chr($_) => sprintf("%%%02X", $_) } 0..255 unless %escapes;
 
     $args{dist} =~ s{^cpan://((([a-zA-Z])[a-zA-Z])[-_a-zA-Z]+)/}
-		    {http://www.cpan.org/modules/by-authors/id/\U$3/$2/$1\E/};
+                    {http://www.cpan.org/modules/by-authors/id/\U$3/$2/$1\E/};
 
     my $file = $args{dist};
     $file =~ s/([^\w\.])/$escapes{$1}/g;
@@ -1091,13 +1085,15 @@ sub _unzip_to_tmpdir {
     my %args = &_args;
 
     require File::Temp;
+    require Cwd;
 
     my $dist   = File::Spec->rel2abs($args{dist});
-    my $tmpdirname = File::Spec->catdir(File::Spec->tmpdir, "parXXXXX");
-    my $tmpdir = File::Temp::mkdtemp($tmpdirname)        
-      or die "Could not create temporary directory from template '$tmpdirname': $!";
+    my $tmpdir = File::Temp::tempdir("parXXXXX", TMPDIR => 1, CLEANUP => 1)
+      or die "Could not create temporary directory: $!";
+    $tmpdir = Cwd::abs_path($tmpdir);  #  symlinks cause Archive::Zip issues on some systems
     my $path = $tmpdir;
     $path = File::Spec->catdir($tmpdir, $args{subdir}) if defined $args{subdir};
+
     _unzip(dist => $dist, path => $path);
 
     chdir $tmpdir;
@@ -1131,51 +1127,50 @@ This function is not exported by default.
 =cut
 
 sub parse_dist_name {
-	my $file = shift;
-	return(undef, undef, undef, undef) if not defined $file;
+    my $file = shift;
+    return(undef, undef, undef, undef) if not defined $file;
 
-	(undef, undef, $file) = File::Spec->splitpath($file);
-	
-	my $version = qr/v?(?:\d+(?:_\d+)?|\d*(?:\.\d+(?:_\d+)?)+)/;
-	$file =~ s/\.(?:par|tar\.gz|tar)$//i;
-	my @elem = split /-/, $file;
-	my (@dn, $dv, @arch, $pv);
-	while (@elem) {
-		my $e = shift @elem;
-		if (
+    (undef, undef, $file) = File::Spec->splitpath($file);
+
+    my $version = qr/v?(?:\d+(?:_\d+)?|\d*(?:\.\d+(?:_\d+)?)+)/;
+    $file =~ s/\.(?:par|tar\.gz|tar)$//i;
+    my @elem = split /-/, $file;
+    my (@dn, $dv, @arch, $pv);
+    while (@elem) {
+        my $e = shift @elem;
+        if (
             $e =~ /^$version$/o
             and not(# if not next token also a version
                     # (assumes an arch string doesnt start with a version...)
                 @elem and $elem[0] =~ /^$version$/o
             )
         ) {
-            
-			$dv = $e;
-			last;
-		}
-		push @dn, $e;
-	}
-	
-	my $dn;
-	$dn = join('-', @dn) if @dn;
+            $dv = $e;
+            last;
+        }
+        push @dn, $e;
+    }
 
-	if (not @elem) {
-		return( $dn, $dv, undef, undef);
-	}
+    my $dn;
+    $dn = join('-', @dn) if @dn;
 
-	while (@elem) {
-		my $e = shift @elem;
-		if ($e =~ /^$version|any_version$/) {
-			$pv = $e;
-			last;
-		}
-		push @arch, $e;
-	}
+    if (not @elem) {
+        return( $dn, $dv, undef, undef);
+    }
 
-	my $arch;
-	$arch = join('-', @arch) if @arch;
+    while (@elem) {
+        my $e = shift @elem;
+        if ($e =~ /^(?:$version|any_version)$/) {
+            $pv = $e;
+            last;
+        }
+        push @arch, $e;
+    }
 
-	return($dn, $dv, $arch, $pv);
+    my $arch;
+    $arch = join('-', @arch) if @arch;
+
+    return($dn, $dv, $arch, $pv);
 }
 
 =head2 generate_blib_stub
@@ -1196,7 +1191,7 @@ Example:
 
   use PAR::Dist;
   use File::Copy 'copy';
-  
+
   generate_blib_stub(
     name => 'MyApp', version => '1.00'
   );
@@ -1211,20 +1206,20 @@ sub generate_blib_stub {
     my %args = &_args;
     my $dist = $args{dist};
     require Config;
-    
-    my $name	= $args{name};
-    my $version	= $args{version};
-    my $suffix	= $args{suffix};
+
+    my $name    = $args{name};
+    my $version = $args{version};
+    my $suffix  = $args{suffix};
 
     my ($parse_name, $parse_version, $archname, $perlversion)
       = parse_dist_name($dist);
-    
+
     $name ||= $parse_name;
     $version ||= $parse_version;
     $suffix = "$archname-$perlversion"
       if (not defined $suffix or $suffix eq '')
          and $archname and $perlversion;
-    
+
     $suffix ||= "$Config::Config{archname}-$Config::Config{version}";
     if ( grep { not defined $_ } ($name, $version, $suffix) ) {
         warn "Could not determine distribution meta information from distribution name '$dist'";
@@ -1237,7 +1232,7 @@ sub generate_blib_stub {
           or die "Could not open META.yml file for writing: $!";
         print META << "YAML" if fileno(META);
 name: $name
-version: $version
+version: '$version'
 build_requires: {}
 conflicts: {}
 dist_name: $name-$version-$suffix.par
@@ -1285,7 +1280,7 @@ sub contains_binaries {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $dist, subdir => 'blib'
@@ -1303,9 +1298,9 @@ sub contains_binaries {
     );
 
     chdir($old_cwd);
-    
+
     File::Path::rmtree([$base_dir]);
-    
+
     return $found ? 1 : 0;
 }
 
@@ -1340,12 +1335,12 @@ sub _MI_can_run {
 # entries with sub references on success.
 sub _get_yaml_functions {
   # reasoning for the ranking here:
-  # - syck is fast and reasonably complete
+  # - XS is the de-facto standard nowadays.
   # - YAML.pm is slow and aging
+  # - syck is fast and reasonably complete
   # - Tiny is only a very small subset
-  # - XS is very new and I'm not sure it's ready for prime-time yet
   # - Parse... is only a reader and only deals with the same subset as ::Tiny
-  my @modules = qw(YAML::Syck YAML YAML::Tiny YAML::XS Parse::CPAN::Meta);
+  my @modules = qw(YAML::XS YAML YAML::Tiny YAML::Syck Parse::CPAN::Meta);
 
   my %yaml_functions;
   foreach my $module (@modules) {
@@ -1378,7 +1373,8 @@ sub _check_tools {
   }
 
   $tools->{zip} = undef;
-  if (eval {require Archive::Zip; 1;}) {
+  # A::Zip 1.28 was a broken release...
+  if (eval {require Archive::Zip; 1;} and $Archive::Zip::VERSION ne '1.28') {
     warn "Using Archive::Zip as ZIP tool.\n" if $DEBUG;
     $tools->{zip} = 'Archive::Zip';
   }
@@ -1387,7 +1383,7 @@ sub _check_tools {
     $tools->{zip} = 'zip';
   }
   else {
-    warn "Found neither Archive::Zip nor ZIP/UNZIP as valid ZIP tools.\n" if $DEBUG;
+    warn "Found neither Archive::Zip (version != 1.28) nor ZIP/UNZIP as valid ZIP tools.\n" if $DEBUG;
     $tools->{zip} = undef;
   }
 
@@ -1404,17 +1400,19 @@ L<PAR>, L<ExtUtils::Install>, L<Module::Signature>, L<LWP::Simple>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt> 2003-2007
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt> 2005-2008
+Steffen Mueller E<lt>smueller@cpan.orgE<gt> 2005-2011
 
 PAR has a mailing list, E<lt>par@perl.orgE<gt>, that you can write to;
 send an empty mail to E<lt>par-subscribe@perl.orgE<gt> to join the list
 and participate in the discussion.
+Archives of the mailing list are available at
+E<lt>https://www.mail-archive.com/par@perl.org/E<gt> or E<lt>https://groups.google.com/g/perl.parE<gt>.
 
-Please send bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
+Please send bug reports to E<lt>https://github.com/rschupp/PAR-Dist/issuesE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2008 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003-2011 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
